@@ -76,6 +76,7 @@ struct _GoaOAuthProvider
  * @get_request_uri_params: Virtual function for goa_oauth_provider_get_request_uri_params().
  * @add_account_key_values: Virtual function for goa_oauth_provider_add_account_key_values().
  * @is_deny_node: Virtual function for goa_oauth_provider_is_deny_node().
+ * @is_identity_node: Virtual function for goa_oauth2_provider_is_identity_node().
  *
  * Class structure for #GoaOAuthProvider.
  */
@@ -115,10 +116,12 @@ struct _GoaOAuthProviderClass
   /* pure virtual */
   gboolean     (*is_deny_node)             (GoaOAuthProvider  *provider,
                                             WebKitDOMNode     *node);
+  gboolean     (*is_identity_node)         (GoaOAuthProvider          *provider,
+                                            WebKitDOMHTMLInputElement *element);
 
   /*< private >*/
   /* Padding for future expansion */
-  gpointer goa_reserved[31];
+  gpointer goa_reserved[30];
 };
 
 GType        goa_oauth_provider_get_type                 (void) G_GNUC_CONST;
@@ -138,6 +141,8 @@ gchar       *goa_oauth_provider_get_identity_sync        (GoaOAuthProvider  *pro
                                                           GError           **error);
 gboolean     goa_oauth_provider_is_deny_node             (GoaOAuthProvider  *provider,
                                                           WebKitDOMNode     *node);
+gboolean     goa_oauth_provider_is_identity_node         (GoaOAuthProvider          *provider,
+                                                          WebKitDOMHTMLInputElement *element);
 gchar       *goa_oauth_provider_parse_request_token_error (GoaOAuthProvider *provider,
                                                            RestProxyCall    *call);
 gchar       *goa_oauth_provider_get_access_token_sync    (GoaOAuthProvider  *provider,
