@@ -1004,8 +1004,9 @@ goa_util_add_row_switch_from_keyfile_with_blurb (GtkGrid      *left,
     {
       GtkWidget *label;
 
-      label = gtk_label_new (blurb);
+      label = gtk_label_new_with_mnemonic (blurb);
       gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+      gtk_label_set_mnemonic_widget (GTK_LABEL (label), switch_);
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     }
 
